@@ -35,7 +35,7 @@ class NotificationStack(Stack):
             # the properties below are optional
             bundle_id=apns_bundle_id,
             certificate=apns_certificate,
-            default_authentication_method="CERTIFICATE", 
+            default_authentication_method="key", 
             enabled=True,
             private_key=apns_private_key,
             # team_id="teamId",
