@@ -26,7 +26,9 @@ class IAMRolesStack(Stack):
 
 
         ## 
-        ## EKS Service Role
+        ## EKS Managed Role
+        eks_managed_role_dictionary = permission.readIAMRolePolicyStatements(iam_roles_dir, "eks_managed_role")
+        self.eks_managed_role = permission.createIAMManagedRole(self, eks_managed_role_dictionary)
         
 
         ##
